$TITLE: CLOSED ECONOMY 2*2 WITH BENCHMARK TAXES IN MCP SYNTAX

$ontext
This example illustrates the treatment of BMK taxes on inputs and
outputs. It is important to be aware that tax rates are interpreted
differently for inputs and outputs:
- tax rates on inputs are specified on a net basis
uc = p*(1 + t)
- tax rates on outputs are specified on a gross basis
uc = p*(1 - t) 

Taxes do not change the underlying technologies or preferences. The important
lesson is to keep track of what reference prices (and related quantities) firms
and consumer face in the benchmark.


Tasks:

(i) Complete the SAM below using the following assumptions
- output tax 20% applying to sector x
- input tax on labor 100% applying to sector x
- CD technologies and preferences

(ii)    Write down the zero-profit condition of sector X in MCP syntax to make
        sure that you understand the concept of reference prices

(iii)   Remove taxes in the counterfactualsImplement the model in MCP scalar
        syntax and do a calibration check 


Hint:   Scale the model such that in the benchmark all market prices are equal 
        unity.

        Applying Shepard's Lemma one has to take the user cost of a good (incl.
        taxes!) for demand derivation. 



TABLE BMFLOW(*,*) BENCHMARK FLOWS

               X       Y       W       CONS     ROWSUM
  X          100            -100                     0
  Y                  100    -100                     0
  UTIL                       200      -200           0
  L            ?     -60                 ?           0
  K          -60     -40               100           0
  TAX_L        ?                         ?
  TAX_PROD     ?                         ?
* COLSUM       0       0        0        0 ;


*----------------- Solution -------------------------------------------------

TABLE BMFLOW(*,*) BENCHMARK FLOWS

               X       Y       W       CONS     ROWSUM
  X          100            -100                     0
  Y                  100    -100                     0
  UTIL                       200      -200           0
  L          -10     -60                70           0
  K          -60     -40               100           0
  TAX_L      -10                        10
  TAX_PROD   -20                        20
* COLSUM       0       0        0        0 ;



* Zero-profit condition for sector x: Cost >= Revenues
 ((pl*(1+tl_x)/pl_bar)**theta_l*(pk/pk_bar)**theta_k >=
						(1-tx_out)*px/ px_bar  

* For convenience: all market prices are equal one!!
 tx_out	 = 20/100
 tl_x	 = 100/100 = 1 
 pl_bar  = 1 + 100% = 2
 pk_bar  = 1
 px_bar  = 1 -20% = 0.8
 theta_l = 20/80 
 theta_k = 60/80
$offtext


POSITIVE VARIABLES
        X    Activity level for X sector
        Y    Activity level for Y sector
        W    Activity level for utility production(Hicksian welfare index)

        PX   Price index for X commodity
        PY   Price index for Y commodity
        PL   Price index for labor
        PK   Price index for capital
        PW   Price index for welfare (expenditure funtion) 

        RA   Consumer income level;


EQUATIONS
        PRF_X   Zero profit for sector X
        PRF_Y   Zero profit for sector Y
        PRF_W   Zero profit for sector W (Hicksian welfare index)

        MKT_X   Supply-demand balance for commodity X
        MKT_Y   Supply-demand balance for commodity Y
        MKT_L   Supply-demand balance for primary factor L
        MKT_K   Supply-demand balance for primary factor L
        MKT_W   Supply-demand balance for aggregate demand

        I_RA    Income definition for RA;


SCALARS
        TL_X            Tax on labor inputs into X production   /1/
        TX_OUT          Output tax on X production              /0.2/
        PX_BAR          Reference price of X for producer       /0.8/
        PLX_BAR         Reference price of labor input into X production /2/;

*       Zero profit conditions are produced for all of the production
*       sectors.  These are interpreted as:

*               Cost of Production Gross of Tax  =  Value of Output

PRF_X..         (PL*(1+TL_X)/PLX_BAR)**0.25*PK**0.75 =E= PX*(1- TX_OUT)/PX_BAR;

PRF_Y..         100 *PL**0.6*PK**0.4   =E= 100 * PY;

PRF_W..         200 * PX**0.5* PY**0.5 =E= 200 * PW;

*       Market clearance conditions for each of the final goods and
*       primary factors.  These are interpreted as:

*               Output plus Initial Endowment  = Intermediate + Final Demand

MKT_X..         100 * X =E= 100 * W * PW/PX;

MKT_Y..         100 * Y =E= 100 * W * PW/PY;

MKT_W..         200 * W =E= RA / PW;

MKT_L..         70  =E= 10*X * (PX*(1-TX_OUT)/PX_BAR)*
                                 PLX_BAR/(PL*(1+TL_X)) + 60 * Y * PY/PL;

MKT_K..         100 =E= 60 * X * (PX*(1-TX_OUT)/PX_BAR)*(1/PK)+ 40 * Y * PY/PK;
                        

*       Income balance states that the level of expenditure (RA)
*       equals the value of factor income plus tax revenue:

I_RA..        RA =E= 70*PL + 100*PK
        + TL_X*PL*10*X * (PX*(1-TX_OUT)/PX_BAR)*
                PLX_BAR/(PL*(1+TL_X))  + 100*X*PX*TX_OUT;


MODEL ALGEBRAIC /PRF_X.X, PRF_Y.Y, PRF_W.W, MKT_X.PX, MKT_Y.PY, MKT_L.PL, 
                 MKT_K.PK, MKT_W.PW, I_RA.RA /;

*       Check the benchmark (benchmark replication):
X.L=1; Y.L=1; W.L=1; PX.L=1; PY.L=1; PK.L=1; PL.L = 1; PW.L=1; RA.L=200;


ALGEBRAIC.ITERLIM = 0;
        SOLVE ALGEBRAIC USING MCP;

* Fix price of labor as the numeraire (this easens the solution process)
PL.FX = 1; 

* Do counterfactual without taxes
ALGEBRAIC.ITERLIM = 2000;
TX_OUT = 0;
TL_X = 0;


SOLVE ALGEBRAIC USING MCP;
