$TITLE: CLOSED ECONOMY 2*2 - CES TECHNOLOGIES AND PREFERENCES

$ontext
TABLE BMFLOW(*,*) BENCHMARK FLOWS

               X       Y       W       RA     ROWSUM
  X          100            -100                     0
  Y                  100    -100                     0
  UTIL                       200      -200           0
  L          -40     -60               100           0
  K          -60     -40               100           0
  COLSUM       0       0        0        0 ;
$offtext       

SCALAR  TAX_L   Tax on labor inputs /0/;

POSITIVE VARIABLES
        X    Activity level for X sector
        Y    Activity level for Y sector
        W    Activity level for utility production(Hicksian welfare index)

        PX   Price index for X commodity
        PY   Price index for Y commodity
        PL   Price index for labor
        PK   Price index for capital
        PW   Price index for welfare (expenditure funtion) 

        RA   Consumer income level;


EQUATIONS
        PRF_X   Zero profit for sector X
        PRF_Y   Zero profit for sector Y
        PRF_W   Zero profit for sector W (Hicksian welfare index)

        MKT_X   Supply-demand balance for commodity X
        MKT_Y   Supply-demand balance for commodity Y
        MKT_L   Supply-demand balance for primary factor L
        MKT_K   Supply-demand balance for primary factor L
        MKT_W   Supply-demand balance for aggregate demand

        I_RA    Income definition for RA;

EQUATIONS
        PRF_X   Zero profit for sector X
        PRF_Y   Zero profit for sector Y
        PRF_W   Zero profit for sector W (Hicksian welfare index)

        MKT_X   Supply-demand balance for commodity X
        MKT_Y   Supply-demand balance for commodity Y
        MKT_L   Supply-demand balance for primary factor L
        MKT_K   Supply-demand balance for primary factor L
        MKT_W   Supply-demand balance for aggregate demand

        I_RA    Income definition for RA;

*       Zero profit conditions are produced for all of the production
*       sectors.  These are interpreted as:

*               Cost of Production Gross of Tax  =  Value of Output

PRF_X..         100 *(0.4*(PL*(1+TAX_L))**(1-0.5) +
                 0.6* PK**(1-0.5))**(1/(1-0.5))  =E= 100 * PX;

PRF_Y..         100 *(0.6*(PL*(1+TAX_L))**(1-0.5) + 
                 0.4* PK**(1-0.5))**(1/(1-0.5)) =E= 100 * PY;

PRF_W..         200 * (0.5*PX**(1-0.5) + 0.5* PY**(1-0.5))**(1/(1-0.5))
                                 =E= 200 * PW;

*       Market clearance conditions for each of the final goods and
*       primary factors.  These are interpreted as:

*               Output plus Initial Endowment  = Intermediate + Final Demand

MKT_X..         100 * X =E= 100 * W * (PW/PX)**0.5;

MKT_Y..         100 * Y =E= 100 * W * (PW/PY)**0.5;

MKT_W..         200 * W =E= RA / PW;

MKT_L..         100  =E= 40 * X * (PX/(PL*(1+TAX_L)))**0.5 +
                                 60 * Y * (PY/ (PL*(1+TAX_L)) )**0.5;

MKT_K..         100 =E= 60 * X * (PX/PK)**0.5 +
                        40 * Y * (PY/PK)**0.5;
                        

*       Income balance states that the level of expenditure (RA)
*       equals the value of factor income plus tax revenue:

I_RA..        RA =E= 100*PL + 100*PK + 
  TAX_L*PL*(40 * X * (PX/(PL*(1+TAX_L)))**0.5 + 60 * Y * 
                (PY/(PL*(1+TAX_L)))**0.5);



MODEL ALGEBRAIC /PRF_X.X, PRF_Y.Y, PRF_W.W, MKT_X.PX, MKT_Y.PY, MKT_L.PL, 
                 MKT_K.PK, MKT_W.PW, I_RA.RA /;

*       Check the benchmark (again):

        X.L=1; Y.L=1; W.L=1; PX.L=1; PY.L=1; PK.L=1; PL.L = 1; PW.L=1;
        RA.L=200;
        TAX_L = 0; 
        SOLVE ALGEBRAIC USING MCP;

*       Apply a 100 % input tax and interpret the results:
        TAX_L = 1;       
        SOLVE ALGEBRAIC USING MCP;

