$TITLE  Model M2x2x1_ur: Illustration of price constraint (weak inequality)

$if not setglobal modus		$setglobal modus	UE
$if not setglobal w_level	$setglobal w_level	0.95


TABLE BENCH(*,*)  Benchmark financial flows 
                Y1     Y2       CONS
        Y1      40		-40
        Y2             40	-40
        L     -20     -10        30 
        K     -20     -30        50 ;

SET     I       Produced goods          /Y1, Y2/,
        F       Factors of production   /L, K/;

ALIAS (I,J), (F,FF);

SCALAR	W_LEVEL		Minimum wage level /%W_LEVEL%/;

SCALAR	TL	Uniform	labor tax /0/;	


PARAMETER       Y0(I)           Benchmark sectoral output,
                FD0(F,I)        Benchmark factor demands,
                C0(I)           Benchmark consumption demand, 
		K0		Capital endowment,
		L0		Labor endowment,
		ALPHA(F,I)      Factor input benchmark value share,
                BETA(I)         Benchmark consumption value share
		M0		Benchmark income of representative agent;


*       Extract values from table
Y0(I)		= BENCH(I,I);          
FD0(F,I)	= -BENCH(F,I);
C0(I)		= -BENCH(I,"CONS");       

K0		= BENCH("K","CONS");     
L0		= BENCH("L","CONS");     
M0		= K0 + L0;

ALPHA(F,I)	= FD0(F,I) / Y0(I);
BETA(I)		= C0(I) / M0;


DISPLAY Y0, FD0, C0, ALPHA, BETA;


POSITIVE VARIABLES
        Y(I)		Production activity level

        p(I)		Commodity price 
        w		Wage rate
	r		Rental rate

	M		Consumer income level

	ur		Unemployment rate ;


EQUATIONS
        PRF_Y(I)	Zero profit in production

        MKT_Y(I)	Supply-demand balance for commodities
        MKT_L		Supply-demand balance for labor
        MKT_K		Supply-demand balance for capital

        RA_M		Income definition for RA
	
	MIN_WAGE	Minimum wage level;


*       Zero profit conditions are produced for all of the production
*       sectors.  These are interpreted as:

*               Cost of Production Gross of Tax  =  Value of Output

PRF_Y(I)..         Y0(I) * (w*(1+TL))**alpha("L",I)* (r**alpha("K",I))  =E= Y0(I) * P(I);

*       Market clearance conditions for each of the final goods and
*       primary factors.  These are interpreted as:

*               Output plus Initial Endowment  = Intermediate + Final Demand

MKT_Y(I)..      Y0(I) * Y(I) =E= C0(I) * M/(P(I)*M0);

MKT_L..		L0*(1-ur)  =E= SUM(I, FD0("L",I)* Y(I) * P(I)/(w*(1+TL)));

MKT_K..		K0  =E= SUM(I, FD0("K",I)* Y(I) * P(I)/r);


*       Income balance states that the level of expenditure (RA)
*       equals the value of factor income plus tax revenue:

RA_M..		M =E=      L0*w*(1-ur) + K0*r
			 + SUM(I, w*TL* (FD0("L",I)* Y(I) * P(I)/(w*(1+TL))));


MIN_WAGE..	(w/ PROD(I, P(I)**BETA(I))) =G= W_LEVEL;

MODEL M2x2x1_ur /PRF_Y.Y, MKT_Y.P, MKT_L.w, MKT_K.r, RA_M.M, MIN_WAGE.ur /;

*       Check the benchmark (benchmark replication):
Y.L(I)=1;  P.L(I)=1; r.FX=1; w.L=1; M.L=M0; ur.L = 0;

M2x2x1_ur.ITERLIM = 0;
SOLVE M2x2x1_ur USING MCP;


*	Proceed with Tax Counterfactual

M2x2x1_ur.ITERLIM = 1000;

SCALAR	FE	Flag for employment modus /0/; 
$if %modus%==FE		FE=1;
ur.FX$FE		= 0;


SET SC		Tax scenarios	/T0, T05, T10, T15, T20, T25, T30, T35, T40, T45, T50/;

PARAMETERS	
		TAXLEVEL(SC)	Ad valorem tax rate /T0 0, T05 5, T10 10, T15 15, T20 20, T25 25, T30 30, T35 35, T40 40, T45 45, T50 50/
		U_RATE(SC)	Unemployment rate,
		REVENUE(SC)	Tax revenues,
		WELFARE(SC)	Welfare implications as percentage change in HEV of income;

LOOP (SC,
	TL = TAXLEVEL(SC)/100;
SOLVE M2x2x1_ur USING MCP; 

REVENUE(SC)	= SUM(I, w.L*TL* (FD0("L",I)* Y.L(I) * P.L(I)/(w.L*(1+TL))))/ PROD(I,P.L(I)**BETA(I));
U_RATE(SC)	= ur.l;
WELFARE(SC)	= ROUND(100*((M.L/(PROD(I,P.L(I)**BETA(I))))/M0 - 1), 1);
);

DISPLAY REVENUE, U_RATE, WELFARE;

