$TITLE: CLOSED ECONOMY 2*2 IN MPSGE VECTOR SYNTAX


$ontext
The stylized economy is described as follows:
(i)     Agents: two producers, one representative household
(ii)    Behaviorial rules:
        producers maximize profits subject to technological constraints
        consumers maximize utility subject to budget constraint
(iii)   Market structure: perfectly competitive markets
(iv)    Technologies, preferences and resource endowments
        Two factors: capital K and labour L
        Cobb-Douglas functions for producer (goods) S2 and S2 with inputs K & L
        Cobb-Douglas utility function in goods S1 and S2
(v)     Benchmark equilibrium as given below
$offtext

*SAM: ROWS ARE COMMDITIES, COLUMNS ARE ACTIVITIES AND DEMANDS

TABLE BMFLOW(*,*) BENCHMARK FLOWS

               X       Y       W       CONS     ROWSUM
  X          100            -100                     0
  Y                  100    -100                     0
  UTIL                       200      -200           0
  L          -40     -60               100           0
  K          -60     -40               100           0
* COLSUM       0       0        0        0
                                                        ;


*       Formulation in MPSGE vector syntax 
*       Use of GAMS as front-end for data handling

SETS    I       Produced goods  /X, Y/,
        F       Factors pr production /L labour, K capital/; 

ALIAS (FF,F), (I,J);


PARAMETERS      YBAR(I)         Benchmark output levels
                FDBAR(F,I)      Benchmark factor inputs
                CBAR(I)         Benchmark final demands
                ENDOW(F)        Factor endowments
                UBAR            Benchmark expenditure (consumption);

*     Extract values from the table:
YBAR(I)         = BMFLOW(I,I);
FDBAR(F,I)      = -BMFLOW(F,I);
CBAR(I)         = -BMFLOW(I,"W");
UBAR            = SUM(I,CBAR(I));
ENDOW(F)        = BMFLOW(F,"CONS");

*---------- Formulation in MPSGE ---------------------------------------------

$ONTEXT
$MODEL:BASIC

$SECTORS:
        Z(I)   ! Activity level for sectors 
        U      ! Activity level for utility production(Hicksian welfare index)

$COMMODITIES:
        P(I)    ! Price index for commodities
        PF(F)   ! Price index for factors
        PW      ! Price index for welfare (expenditure funtion) 

$CONSUMERS:
        RA      ! Representative consumer

$PROD:Z(I) s:1
        O:P(I)        Q:YBAR(I)       
        I:PF(F)       Q:FDBAR(F,I)

$PROD:U  s:1
        O:PW          Q:UBAR
        I:P(I)        Q:CBAR(I)

$DEMAND:RA
        D:PW          Q:UBAR
        E:PF(F)       Q:ENDOW(F)

$OFFTEXT

$SYSINCLUDE mpsgeset BASIC

        BASIC.WORKSPACE = 4;

* Do benchmark replication check 
        BASIC.ITERLIM = 0;
$INCLUDE BASIC.GEN
        SOLVE BASIC USING MCP;

