$TITLE  Model M4-1S: Small open economy model.  Two goods, two factors.

$ontext

James R. Makusen
Thomas F. Rutherford

Department of Economics
University of Colorado

November, 1995 (revised)

This model illustrates the representation of international trade 
flows in an open economy model.  In this model, the foreign country
is not explicitly modelled.  Trade possibilities are modelled by four
activities which transform domestic goods into "foreign exchange" and
vice versa.

This model is based on the Heckscher-Ohlin assumption that domestic,
imported and exported goods are perfect substitutes.

Two possible trade activities, exports of good 2 and imports of good
1, are idle.  We presume that the export price for good 2 less than
one and the import price for good 1 is greater than one.

                Production Sectors                      Consumer

Markets   |     X1      X2      E1      M2      W       CONS
------------------------------------------------------------------
P1        |     150             -50             -100
P2        |             50              50      -100
PL        |     -100    -20                             120
PK        |     -50     -30                             80
PW        |                                     200     -200
PFX       |                     50      -50
------------------------------------------------------------------

$offtext

SCALAR          PE2     Export price of good 2 / 0.99/
                PM1     Import price of good 1 / 1.01/
                PE1     Export price of good 1 / 1   /
                PM2     Import price of good 2 / 1   /
                TM2     Import tariff for good 2 / 0/;

$ONTEXT

$MODEL:HO_TRADE

$SECTORS:
        X1      ! Production index for good 1
        X2      ! Production index good 2
        E1      ! Export level of good 1
        E2      ! Export level of good 2
        M1      ! Import level of good 1
        M2      ! Import level of good 2
        W       ! Welfare index 

$COMMODITIES:
        P1      ! Price index for good 1
        P2      ! Price index for good 1        
        PFX     ! Read exchange rate index
        PW      ! Welfare price index
        PL      ! Wage index
        PK      ! Capital rental index

$CONSUMERS:
        CONS    ! Income level for representative agent

*       Cobb-Douglas production in both sectors:

$PROD:X1  s:1
        O:P1    Q:150
        I:PL    Q:100
        I:PK    Q:50
 
$PROD:X2  s:1
        O:P2    Q:50
        I:PL    Q:20
        I:PK    Q:30

*       We scale the export price for good 1 and the import price
*       for good 2 to both be unity:

$PROD:E1
        O:PFX   Q:PE1
        I:P1    Q:1
 
$PROD:M2
        O:P2    Q:1
        I:PFX   Q:PM2    A:CONS T:TM2

*       The following trade activities are not operated in the benchmark
*       period:

$PROD:E2
        O:PFX   Q:PE2
        I:P2    Q:1

$PROD:M1
        O:P1    Q:1
        I:PFX   Q:PM1

*       Cobb-Douglas preferences:

$PROD:W   s:1
        O:PW    Q:200
        I:P1    Q:100
        I:P2    Q:100

$DEMAND:CONS
        D:PW    Q:200
        E:PL    Q:120
        E:PK    Q:80

$OFFTEXT
$SYSINCLUDE mpsgeset HO_TRADE

*       We replicate the benchmark by assuming default values of
*       unity for production activities and prices, but we must 
*       explicitly specify benchmark values for the trade activities
*       because they are not unity:

E2.L = 0;
M1.L = 0;
E1.L = 50;
M2.L = 50;

HO_TRADE.ITERLIM = 0;
$INCLUDE HO_TRADE.GEN
SOLVE HO_TRADE USING MCP;
HO_TRADE.ITERLIM = 2000;

* Counterfactual experiments are to levy a 10% and then a 20% import 
* tariff on C2.  10% tariff is prohibitive.

TM2 = 0.05;
$INCLUDE HO_TRADE.GEN
SOLVE HO_TRADE USING MCP;

TM2 = 0.10;
$INCLUDE HO_TRADE.GEN
SOLVE HO_TRADE USING MCP;

$ontext

Excercises:

(i) Compare the welfare cost of tariffs in this model with the results
from a Ricardo-Viner-Jones (specific factors) model.  To do so, replace
the mobile capital stock by sector-specific capital stocks (drop PK
and add PK1 and PK2).

(ii) Multiply all of the international prices (PE1,PE2,PM1,PM2) by a
positive constant and verify that the benchmark equilibrium is undisturbed --
all that changes is that PFX changes proportionately.

$offtext
