$TITLE	Simple GAMS/MPSGE Model Illustrating HHP Decomposition Method

set	r	Regions /r1*r3/;

alias (r,rr,s);

parameter	gdp(r)		GDP Index
		c0(r,r)		Base year consumption
		tm(r)		Tariff rates;

gdp(r) = ord(r);
c0(r,rr) = gdp(r) * gdp(rr);
tm(r) = 0;

$ontext

$model:exchange

$sectors:
	c(r)		!	Consumption demand

$commodities:
	p(r)		!	Macro output
	pc(r)		!	Consumption price

$consumers:
	ra(r)		!	Representative agent

$prod:c(r) s:2  mm:4
	o:pc(r)		q:gdp(r)
	i:p(rr)$(not sameas(r,rr))	q:c0(rr,r)  mm:  a:ra(r) t:tm(r)
	i:p(r)		q:c0(r,r)  

$demand:ra(r)  
	e:p(r)		q:gdp(r)
	d:pc(r)		q:gdp(r)


$report:
	v:w(r)	w:ra(r)

$offtext
$sysinclude mpsgeset exchange

*	Solve the initial (zero tariff) equilibrium:

$include exchange.gen
solve exchange using mcp;



* ------------------------------------------------------------------

$stitle  GAMS Code for Decomposition

set     t               Steps in line integral /t0*t10/;

parameter
        tm0(r)          Base value of policy instrument
        deltatm(r)      Change in policy instrument
        w0(r,t)         Value of W along integral over t
        dwdtm(r,t,r)    Value of partial derivatives along integral
        epsilon         Differentiation perturbation
        decomp(r,r)     Decomposition of changes in w
        handshake       Approximation error 
        dt              Step size in integral over t;

*  Step size for the line integral:

dt = 1 /(card(t)-1);

*   Define a reasonable value for numerical differencing:

epsilon = 0.0001;
tm0(r) = 0;
deltatm(r) = 0.1;

tm(r) = tm0(r);
loop(t,

$include exchange.gen
	solve exchange using mcp;

        w0(r,t) = w.l(r);

        loop(s,
                tm(s) = tm(s) + epsilon;
$include exchange.gen
		solve exchange using mcp;
                dwdtm(r,t,s) = (w.l(r) - w0(r,t)) / epsilon;
                tm(s) = tm(s) - epsilon;
        );

        tm(r) = tm(r) + dt * deltatm(r);

);

decomp(r,rr) = sum(t, dwdtm(r,t,rr) * deltatm(rr) * dt);

handshake(r) = sum(rr, decomp(r,rr)) - sum(t$(ord(t) gt 1), w0(r,t) -
w0(r,t-1));

display decomp, handshake;

